@@ -99,20 +99,27 @@ class ASL(SystemCallSolver):
         #if self._problem_format is None or self._problem_format == ProblemFormat.nl:
         #   ...
 
-        cmd = [executable, problem_files[0], '-AMPL']
+        cmd = [executable, '-s', problem_files[0]]
         if self._timer:
             cmd.insert(0, self._timer)
-            
+        
+        # GAH: I am going to re-add the code by Zev that passed options through
+        # to the command line. I'm not sure what solvers this method of passing options
+        # through the envstr variable works for, but it does not seem to work for cplex
+        # or gurobi
         opt=[]
         for key in self.options:
             if key is 'solver':
                 continue
             if isinstance(self.options[key],basestring) and ' ' in self.options[key]:
                 opt.append(key+"=\""+str(self.options[key])+"\"")
+                cmd.append(str(key)+"="+str(self.options[key]))
             elif key == 'subsolver':
                 opt.append("solver="+str(self.options[key]))
+                cmd.append(str(key)+"="+str(self.options[key]))
             else:
                 opt.append(key+"="+str(self.options[key]))
+                cmd.append(str(key)+"="+str(self.options[key]))
 
         envstr = "%s_options" % self.options.solver
         # Merge with any options coming in through the environment
