@@ -74,11 +74,6 @@ class CPLEXSHELL(ILMLicensedSystemCallSolver):
         kwds['type'] = 'cplex'
         ILMLicensedSystemCallSolver.__init__(self, **kwds)
 
-        # We are currently invoking CPLEX via the command line, with input re-direction. As opposed
-        # to writing our own ilcplex-based C++ driver. Consequently, we need to define an attribute
-        # to retain the execution script name.
-        self.cplex_script_file_name = None
-
         # NOTE: eventually both of the following attributes should be migrated to a common base class.
         # is the current solve warm-started? a transient data member to communicate state information
         # across the _presolve, _apply_solver, and _postsolve methods.
@@ -242,13 +237,11 @@ class CPLEXSHELL(ILMLicensedSystemCallSolver):
         #
         # Write the CPLEX execution script
         #
-        self.cplex_script_file_name = pyutilib.services.TempfileManager.create_tempfile(suffix = '.cplex.script')
-        cplex_script_file = open(self.cplex_script_file_name,'w')
-        cplex_script_file.write("set logfile "+self.log_file+"\n")
+        script = "set logfile %s\n" % ( self.log_file, )
         if self._timelimit is not None and self._timelimit > 0.0:
-            cplex_script_file.write("set timelimit "+`self._timelimit`+"\n")
+            script += "set timelimit %s\n" % ( self._timelimit, )
         if (self.options.mipgap is not None) and (self.options.mipgap > 0.0):
-            cplex_script_file.write("set mip tolerances mipgap "+`self.options.mipgap`+"\n")
+            script += "set mip tolerances mipgap %s\n" % ( self.options.mipgap, )
         for key in self.options:
             if key == 'relax_integrality' or key == 'mipgap':
                 continue
@@ -256,35 +249,46 @@ class CPLEXSHELL(ILMLicensedSystemCallSolver):
                 opt = " ".join(key.split('_'))+" "+str(self.options[key])
             else:
                 opt = " ".join(key.split('_'))+" "+str(self.options[key])
-            cplex_script_file.write("set "+opt+"\n")
-        cplex_script_file.write("read "+problem_files[0]+"\n")
+            script += "set %s\n" % ( opt, )
+        script += "read %s\n" % ( problem_files[0], )
 
         # if we're dealing with an LP, the MST file will be empty.
         if (self.warm_start_solve is True) and (self.warm_start_file_name is not None):
-            cplex_script_file.write("read "+self.warm_start_file_name+"\n")
+            script += "read %s\n" % ( self.warm_start_file_name, )
 
         if 'relax_integrality' in self.options:
-            cplex_script_file.write("change problem lp\n")
+            script += "change problem lp\n"
 
-        cplex_script_file.write("display problem stats\n")
-        cplex_script_file.write("optimize\n")
-        cplex_script_file.write("write " + self.soln_file+"\n")
-        cplex_script_file.write("quit\n")
-        cplex_script_file.close()
+        script += "display problem stats\n"
+        script += "optimize\n"
+        script += "write %s\n" % ( self.soln_file, )
+        script += "quit\n"
 
         # dump the script and warm-start file names for the
         # user if we're keeping files around.
         if self.keepFiles:
-            print "Solver script file=" + self.cplex_script_file_name
+            script_fname = pyutilib.services.TempfileManager.create_tempfile(suffix = '.cplex.script')
+            tmp = open(script_fname,'w')
+            tmp.write(script)
+            tmp.close()
+            
+            print "Solver script file=" + script_fname
             if (self.warm_start_solve is True) and (self.warm_start_file_name is not None):
                 print "Solver warm-start file=" + self.warm_start_file_name
 
         #
         # Define command line
         #
-        if self._problem_format in [ProblemFormat.cpxlp, ProblemFormat.mps]:
-            proc = self._timer + " " + self.executable() + " < " + self.cplex_script_file_name
-        return pyutilib.misc.Bunch(cmd=proc, log_file=self.log_file, env=None)
+        # JDS: I am not sure why we did this test... mostly because if
+        # it ever returned false, 'proc' was never initialized, resulting
+        # in an exception.
+        #if self._problem_format in [ProblemFormat.cpxlp, ProblemFormat.mps]:
+        #    proc = self._timer + " " + self.executable()
+        cmd = [self.executable()]
+        if self._timer:
+            cmd.insert(0, self._timer)
+        return pyutilib.misc.Bunch( cmd=cmd, script=script, 
+                                    log_file=self.log_file, env=None )
 
     def process_logfile(self):
         """
@@ -441,7 +445,7 @@ class CPLEXSHELL(ILMLicensedSystemCallSolver):
                 variable_value = None
                 variable_reduced_cost = None
                 variable_status = None
-                for i in range(1,len(tokens)):
+                for i in xrange(1,len(tokens)):
                     field_name =  tokens[i].split('=')[0]
                     field_value = tokens[i].split('=')[1].lstrip("\"").rstrip("\"")
                     if field_name == "name":
