@@ -597,6 +597,9 @@ class CPLEXDirect(OptSolver):
                 for key_piece in key_pieces:
                     opt_cmd = getattr(opt_cmd,key_piece)
                 opt_cmd.set(self.options[key])
+                
+        if 'relax_integrality' in self.options:
+            self._active_cplex_instance.set_problem_type(self._active_cplex_instance.problem_type.LP)
         
         # and kick off the solve.
         if self.tee == True:
