@@ -30,19 +30,21 @@ glpk_file_flag=None
 
 def configure_glpk():
     global glpk_file_flag
-    if glpk_file_flag is None:
-        glpk_file_flag = False
-        if not pyutilib.services.registered_executable("glpsol") is None:
-            results = pyutilib.subprocess.run(registered_executable('glpsol').get_path()+" --version")[1]
-            lines = results.split('\n') 
-            if len(lines) == 0:
-                return
-            version = lines[0].split(' ')[-1]
-            version.strip()
-            if version[0] == 'v':
-                version=version[1:]
-            _version = map(eval, version.split('.'))
-            glpk_file_flag = tuple(_version) >= (4,42)
+    if glpk_file_flag is not None:
+        return
+    glpk_file_flag = False
+    if registered_executable("glpsol") is None:
+        return
+    errcode, results = pyutilib.subprocess.run(
+        [registered_executable('glpsol').get_path(), "--version"])
+    if errcode == 0:
+        lines = results.split('\n') 
+        if len(lines) == 0 or lines[0] == '':
+            return
+        m = re.search('(\d+)\.(\d+)', lines[0].split()[-1])
+        if m:
+            _version = tuple(int(i) for i in m.groups())
+            glpk_file_flag = _version >= (4,42)
 
 
 # Not sure how better to get these constants, but pulled from GLPK
@@ -165,29 +167,31 @@ class GLPKSHELL ( SystemCallSolver ):
         #
         # Define command line
         #
-        cmd = [self._timer, '"%s"' % executable]
+        cmd = [executable]
+        if self._timer:
+            cmd.insert(0, self._timer)
         for key in self.options:
             opt = self.options[ key ]
-            if isinstance(opt, basestring) and ' ' in opt:
-                cmd.append('--%s "%s"' % (key, str(opt)) )
-            else:
-                cmd.append('--%s %s' % (key, str(opt)) )
+            cmd.extend(["--%s" % key, str(opt)])
+            #if isinstance(opt, basestring) and ' ' in opt:
+            #    cmd.append('--%s "%s"' % (key, str(opt)) )
+            #else:
+            #    cmd.append('--%s %s' % (key, str(opt)) )
 
         if self._timelimit is not None and self._timelimit > 0.0:
-            cmd.append('--tmlim ' + str(self._timelimit))
+            cmd.extend(['--tmlim', str(self._timelimit)])
 
-        cmd.append('--write ' + self._rawfile )
-        cmd.append('--wglp ' + self._glpfile )
+        cmd.extend(['--write', self._rawfile])
+        cmd.extend(['--wglp', self._glpfile])
 
         if self._problem_format == ProblemFormat.cpxlp:
-            cmd.append('--cpxlp ' + problem_files[0])
+            cmd.extend(['--cpxlp', problem_files[0]])
         elif self._problem_format == ProblemFormat.mps:
-            cmd.append('--freemps ' + problem_files[0])
+            cmd.extend(['--freemps', problem_files[0]])
         elif self._problem_format == ProblemFormat.mod:
-            cmd.append('--math ' + problem_files[0])
-            cmd.append('--data "%s"' % fname for fname in problem_files[1:])
-
-        cmd = ' '.join(cmd)
+            cmd.extend(['--math', problem_files[0]])
+            for fname in problem_files[1:]:
+                cmd.extend(['--data', fname])
 
         return Bunch(cmd=cmd, log_file=self.log_file, env=None)
 
