@@ -92,28 +92,31 @@ class GLPKSHELL_old(SystemCallSolver):
         #
         # Define command line
         #
-        cmd = [self._timer, '"%s"' % executable]
+        cmd = [executable]
+        if self._timer:
+            cmd.insert(0, self._timer)
         for key in self.options:
-            if isinstance(self.options[key], basestring) \
-                   and ' ' in self.options[key]:
-                cmd.append('--%s "%s"' % (key, str(self.options[key])))
-            else:
-                cmd.append('--%s %s' % (key, str(self.options[key])))
+            opt = self.options[ key ]
+            cmd.extend(["--%s" % key, str(opt)])
+            #if isinstance(self.options[key], basestring) \
+            #       and ' ' in self.options[key]:
+            #    cmd.append('--%s "%s"' % (key, str(self.options[key])))
+            #else:
+            #    cmd.append('--%s %s' % (key, str(self.options[key])))
 
         if self._timelimit is not None and self._timelimit > 0.0:
-            cmd.append('--tmlim ' + str(self._timelimit))
+            cmd.extend(['--tmlim', str(self._timelimit)])
 
-        cmd.append('--output ' + self.soln_file)
+        cmd.extend(['--output', self.soln_file])
 
         if self._problem_format == ProblemFormat.cpxlp:
-            cmd.append('--cpxlp ' + problem_files[0])
+            cmd.extend(['--cpxlp', problem_files[0]])
         elif self._problem_format == ProblemFormat.mps:
-            cmd.append('--freemps ' + problem_files[0])
+            cmd.extend(['--freemps', problem_files[0]])
         elif self._problem_format == ProblemFormat.mod:
-            cmd.append('--math ' + problem_files[0])
-            cmd.append('--data "%s"' % fname for fname in problem_files[1:])
-
-        cmd = ' '.join(cmd)
+            cmd.extend(['--math', problem_files[0]])
+            for fname in problem_files[1:]:
+                cmd.extend(['--data', fname])
 
         return Bunch(cmd=cmd, log_file=self.log_file, env=None)
 
