@@ -22,7 +22,7 @@ from CPLEXDirect import CPLEXDirect
 from GUROBI import GUROBI
 from gurobi_direct import gurobi_direct
 from ASL import ASL, MockASL
-#from NLWRITE import NLWRITE
+from XPRESS import XPRESS, MockXPRESS
 
 #
 # Interrogate the CBC executable to see if it recognizes the -AMPL flag
