@@ -415,6 +415,12 @@ class gurobi_direct ( OptSolver ):
         # 'ResultFile', 'ImproveStartTime', 'ImproveStartGap', 'Threads', 'Dummy', 'OutputFlag']
         for key in self.options:
             prob.setParam( key, self.options[key] )
+            
+        if 'relax_integrality' in self.options:
+            for v in prob.getVars():
+                if v.vType != GRB.CONTINUOUS:
+                    v.vType = GRB.CONTINUOUS
+            prob.update()
 
         
         # Actually solve the problem.
